SeedKitModuleApiLocale class

Constructors

SeedKitModuleApiLocale()

Properties

exception_failed_load_data String
Не удалось загрузить данные
no setter
exception_internal_error String
Внутренняя ошибка
no setter
exception_internet_connection_error_description String
Проверьте подключение и попробуйте снова
no setter
exception_internet_connection_error_title String
Нет подключения к интернету
no setter
exception_server_connect_error_description String
Не удалось подключиться к серверу
no setter
exception_server_connect_error_title String
Ошибка подключения к серверу
no setter
exception_server_timeout_description String
Сервер не ответил вовремя
no setter
exception_server_timeout_title String
Время ожидания истекло
no setter
exception_something_went_wrong String
Что-то пошло не так
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current SeedKitModuleApiLocale
no setter

Constants

delegate → const AppLocalizationDelegate