ApiClient class abstract

Абстрактная реализации клиента для Provider реализаций

Implementers

Constructors

ApiClient({List<Interceptor> interceptors = const [], Duration timeout = const Duration(seconds: 15), DioCacheEnum cacheEnum = .none})

Properties

getAccessToken String?
no setterinherited
getAuthStatusStream Stream<AuthStatusEnum>
no setterinherited
getUserId String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batch<T>(String path, {required PaginationModel pagination, Map<String, dynamic>? queryParameters, Options? options, RequestEnum type = .get, List<JsonFieldAliasModel> jsonSchemas = const [], required dynamic mapper(dynamic json)}) Future<Either<BaseException, T>>
delete<T>(String path, {dynamic body, Map<String, dynamic>? queryParameters, required T mapper(dynamic json)}) Future<Either<BaseException, T>>
download(String path, {Map<String, dynamic>? params, OnProgressFunction? onProgress, RequestEnum type = .get, required Future<String> saver(Uint8List bytes)}) Future<Either<BaseException, String>>
get<T>(String path, {Map<String, dynamic>? queryParameters, required dynamic mapper(dynamic json), Options? options, OnProgressFunction? onProgress, List<JsonFieldAliasModel> jsonSchemas = const []}) Future<Either<BaseException, T>>
initTokenManager({required RepeatRequestUserCase repeatRequest, required RefreshTokenRequestUserCase refreshTokenRequest, required dynamic getTokenInterseptor(InterceptorsWrapper interseptor)}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch<T>(String path, {dynamic body, required T mapper(dynamic json)}) Future<Either<BaseException, T>>
post<T>(String path, {dynamic body, Options? options, required T mapper(dynamic json)}) Future<Either<BaseException, T>>
put<T>(String path, {dynamic body, required T mapper(dynamic json)}) Future<Either<BaseException, T>>
toString() String
A string representation of this object.
inherited
upload<T>(String path, {required List<File> files, required T mapper(dynamic json)}) Future<Either<BaseException, T>>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

batchKey String
no setter