AuthUrls class abstract
Constructors
- AuthUrls()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- softDeleteSuffix ↔ String
-
getter/setter pair
Static Methods
-
softDelete(
String userId) → String
Constants
- authVkCallBack → const String
- authYandexCallBack → const String
- getSms → const String
- hardDelete → const String
- login → const String
- loginVk → const String
- loginYandex → const String
- logout → const String
- refreshToken → const String
- sendSmsCode → const String