AuthProfileModel class

Базовый прфоиль авторизации

Constructors

AuthProfileModel({required String id, required String refreshToken, required String accessToken})
AuthProfileModel.fromJson(String source)
factory
AuthProfileModel.fromMap(Map<String, dynamic> map)
factory

Properties

accessToken String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
refreshToken String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited