JsonFieldAliasModel class

Модель нормализации

Constructors

JsonFieldAliasModel(List<String> aliases)
const

Properties

aliases List<String>
index == 0 - целевой нейминг. Все остальные будут преобразованы в целевой
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited