SeedKitModuleApiLocale class
Constructors
Properties
- exception_failed_load_data → String
-
Не удалось загрузить данныеno setter - exception_internal_error → String
-
Внутренняя ошибкаno setter - exception_internet_connection_error_description → String
-
Проверьте подключение и попробуйте сноваno setter - exception_internet_connection_error_title → String
-
Нет подключения к интернетуno setter - exception_server_connect_error_description → String
-
Не удалось подключиться к серверуno setter - exception_server_connect_error_title → String
-
Ошибка подключения к серверуno setter - exception_server_timeout_description → String
-
Сервер не ответил вовремяno setter - exception_server_timeout_title → String
-
Время ожидания истеклоno setter - exception_something_went_wrong → String
-
Что-то пошло не такno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → SeedKitModuleApiLocale
-
no setter
Static Methods
-
load(
Locale locale) → Future< SeedKitModuleApiLocale> -
maybeOf(
BuildContext context) → SeedKitModuleApiLocale? -
of(
BuildContext context) → SeedKitModuleApiLocale
Constants
- delegate → const AppLocalizationDelegate