AuthProvider class
Api провайдер авторизации
Constructors
Properties
- getAccessToken → String?
-
no setterinherited
-
getAuthStatusStream
→ Stream<
AuthStatusEnum> -
no setterinherited
- getUserId → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batch<
T> (String path, {required PaginationModel pagination, Map< String, dynamic> ? queryParameters, Options? options, RequestEnum type = .get, List<JsonFieldAliasModel> jsonSchemas = const [], required dynamic mapper(dynamic json)}) → Future<Either< BaseException, T> > -
inherited
-
delete<
T> (String path, {dynamic body, Map< String, dynamic> ? queryParameters, required T mapper(dynamic json)}) → Future<Either< BaseException, T> > -
inherited
-
download(
String path, {Map< String, dynamic> ? params, OnProgressFunction? onProgress, RequestEnum type = .get, required Future<String> saver(Uint8List bytes)}) → Future<Either< BaseException, String> > -
inherited
-
get<
T> (String path, {Map< String, dynamic> ? queryParameters, required dynamic mapper(dynamic json), Options? options, OnProgressFunction? onProgress, List<JsonFieldAliasModel> jsonSchemas = const []}) → Future<Either< BaseException, T> > -
inherited
-
getAuthUrlVk(
) → Future< Either< BaseException, String> > -
getAuthUrlYandex(
) → Future< Either< BaseException, String> > -
getAuthVkCallback(
Map< String, dynamic> ? params) → Future<Either< BaseException, void> > -
getAuthYandexCallback(
Map< String, dynamic> ? params) → Future<Either< BaseException, void> > -
hardDelete(
) → Future< Either< BaseException, void> > -
initTokenManager(
{required RepeatRequestUserCase repeatRequest, required RefreshTokenRequestUserCase refreshTokenRequest, required dynamic getTokenInterseptor(InterceptorsWrapper interseptor)}) → void -
inherited
-
login(
AuthLoginParams params) → Future< Either< BaseException, AuthProfileModel> > -
logout(
) → Future< Either< BaseException, void> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch<
T> (String path, {dynamic body, required T mapper(dynamic json)}) → Future< Either< BaseException, T> > -
inherited
-
post<
T> (String path, {dynamic body, Options? options, required T mapper(dynamic json)}) → Future< Either< BaseException, T> > -
inherited
-
put<
T> (String path, {dynamic body, required T mapper(dynamic json)}) → Future< Either< BaseException, T> > -
inherited
-
sendCode(
AuthPhoneParams params) → Future< Either< BaseException, void> > -
sendSms(
String phone) → Future< Either< BaseException, void> > -
softDelete(
) → Future< Either< BaseException, void> > -
toString(
) → String -
A string representation of this object.
inherited
-
upload<
T> (String path, {required List< File> files, required T mapper(dynamic json)}) → Future<Either< BaseException, T> > -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited